@@ -1,10 +1,6 @@
-#include <libprofile.h>
-
 #include "profilechangerwidget.h"
 #include "ui_profilechangerwidget.h"
 
-using namespace std;
-
 const QString iconSilent = "/usr/share/icons/hicolor/48x48/hildon/statusarea_silent.png";
 const QString iconGeneral = "/usr/share/icons/hicolor/48x48/hildon/statusarea_volumelevel4.png";
 
@@ -28,8 +24,39 @@ ProfileChangerWidget::~ProfileChangerWidget()
     delete ui;
 }
 
+QString ProfileChangerWidget::getProfileName() {
+    QString profileName = "";
+    QDBusMessage msg = QDBusMessage::createMethodCall(
+        "com.nokia.profiled", // --dest
+        "/com/nokia/profiled", // destination object path
+        "com.nokia.profiled", // message name (w/o method)
+        "get_profile" // method
+    );
+    msg = QDBusConnection::systemBus().call(msg);
+
+    if (msg.type() == QDBusMessage::ErrorMessage) {
+        QErrorMessage* err = new QErrorMessage();
+        err->showMessage(msg.errorMessage());
+    } else if(msg.type() == QDBusMessage::ReplyMessage) {
+        profileName = msg.arguments().at(0).toString();
+    }
+    return profileName;
+}
+
+void ProfileChangerWidget::setProfile(QString profileName) {
+    QDBusMessage msg = QDBusMessage::createMethodCall(
+        "com.nokia.profiled", // --dest
+        "/com/nokia/profiled", // destination object path
+        "com.nokia.profiled", // message name (w/o method)
+        "set_profile" // method
+    );
+    msg << profileName;
+    msg = QDBusConnection::systemBus().call(msg);
+}
 void ProfileChangerWidget::refreshIcon() {
-    if ( string( profile_get_profile() ) == "silent" ) {
+    QString profileName = this->getProfileName();
+
+    if ( profileName == "silent" ) {
         showIconSilent(); 
     }
     else {
@@ -47,11 +74,12 @@ void ProfileChangerWidget::showIconGeneral() {
 }
 
 void ProfileChangerWidget::switchProfile() {
-    if ( string(profile_get_profile()) == "silent" ) {
-        profile_set_profile("general");
+    QString profileName = this->getProfileName();
+    if ( profileName == "silent" ) {
+        this->setProfile("general");
     }
     else {
-        profile_set_profile("silent");
+        this->setProfile("silent");
     }
 }  
 
